#
# spec file for package tinyssh
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tinyssh
Version:        20240101
Release:        2.2
Summary:        A minimalistic SSH server which implements only a subset of SSHv2 features
License:        CC0-1.0
Group:          Productivity/Networking/SSH
URL:            https://tinyssh.org/
Source:         https://github.com/janmojzis/tinyssh/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         tinyssh-gcc14-compat.patch

%description
tinyssh is a minimalistic SSH server which implements only a subset of SSHv2
features. It supports only secure cryptography (minimum 128-bit security,
protected against cache-timing attacks) and doesn't implement unnecessary
features (such as SSH1 protocol, compression, ...) or older crypto (such as
RSA, DSA, HMAC-MD5, HMAC-SHA1, 3DES, RC4, ...). tinysshd doesn't implement
unsafe features (such as password or hostbased authentication) or doesn't
use dynamic memory allocation (no allocation failures, etc.)

%prep
%setup -q
%patch -P 0 -p1
echo %{optflags} > conf-cflags
echo %{_sbindir} > conf-bin
echo %{_mandir} > conf-man
echo gcc > conf-cc

%build
%make_build

%install
%make_install

%files
%license LICENCE
%doc README*
%{_sbindir}/tinysshd
%{_sbindir}/tinysshd-makekey
%{_sbindir}/tinysshd-printkey
%{_mandir}/man8/tinysshd-makekey.8%{?ext_man}
%{_mandir}/man8/tinysshd-printkey.8%{?ext_man}
%{_mandir}/man8/tinysshd.8%{?ext_man}
%{_mandir}/man8/tinysshnoneauthd.8%{?ext_man}

%changelog
* Thu Jun 13 2024 Gus Kenion <gus.kenion@suse.com>
- Compatibility fix for upcoming gcc14 release.
  * tinyssh-gcc14-compat.patch adds a missing #include statement
    that prevents tinyssh from building with gcc14
* Sat Jan 27 2024 Dirk Müller <dmueller@suse.com>
- update to 20240101 (bsc#1218197, CVE-2023-48795):
  * fixed channel_forkpty() race condition between close(slave)
    in parent process and login_tty(slave) in child process
  * fixed behavior when using terminal mode and stdin redirected
    to /dev/null 'ssh -tt -n'
  * added an 'strict-key' key exchange kex-strict-
    s-v00@openssh.com (Mitigates CVE-2023-48795 "Terrapin
    attack")
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 20230101:
  * LICENCE update from  public-domain to CC0,
  * public domain works differently depending on the country,
  * to avoid it, set explicitly CC0
  * fixed sysdep tests, tnx Johannes Nixdorf
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 20220801:
  * tinyssh/getln.c don't close fd in case of error
  * use null fields in utmpx calls for logout
  * do not reverse the argument order in LIBS
  * fill utmp(x)'s ut_addr_v6 field when it exists
  * updated crypto/crypto_onetimeauth_poly1305.c
* Thu May  5 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 20220311:
  * fixed build on big-endian platforms
  * use PACKET_LIMIT/2 as incoming maximum packet size,
    it's workaround for packets with miscalculated packet_length
  * add tinysshnoneauthd #29
  * fixed return error message when second channel is requested
  * man/tinysshd-{make,print}key.1 -> man/tinysshd-{make,print}key.8
  * add tools/tinyssh-convert
  * fix log error messages
  * honor "max packet size" requested from the client
  * removed sntrup4591761x25519-sha512@tinyssh.org
  * added sntrup761x25519-sha512@openssh.com
* Tue Jan  1 2019 Karol Babioch <kbabioch@suse.de>
- Update to version 20190101
  * removed aes256,nistp256,hmacsha256
  * added posquantum KEX sntrup4591761x25519-sha512@tinyssh.org
* Fri Dec  7 2018 Karol Babioch <kbabioch@suse.de>
- Update to version 20181206
  * tinysshd binary optimized for smaller size
  * created multi-call tinysshd binary
* Sat Feb  3 2018 kbabioch@suse.com
- Initial package
